@@ -10,7 +10,7 @@ class Model:
     _field_class = ModelField
 
     def __init__(self, **kwargs):
-        for field_name in self.fields:
+        for field_name in self.get_fields():
             field_value = kwargs.get(field_name, None)
             setattr(self, field_name, field_value)
 
@@ -21,11 +21,21 @@ class Model:
         return '{}(fields={!r})'.format(type(self).__name__, list(self._get_fields()))
 
     def _get_fields(self):
-        for field_name in self.fields:
-            allow_empty = '__all__' in self.allow_empty or field_name in self.allow_empty
+        allow_empty_fields = self.get_allow_empty()
+        for field_name in self.get_fields():
+            allow_empty = '__all__' in allow_empty_fields or field_name in allow_empty_fields
             field_value = getattr(self, field_name)
             yield self._field_class(self, field_name, field_value, allow_empty)
 
+    def get_fields(self):
+        assert self.fields, ('{} should include a fields attribute or override '
+                             'the get_fields method'.format(type(self).__name__))
+
+        return self.fields
+
+    def get_allow_empty(self):
+        return self.allow_empty
+
     def is_empty(self, value: Any) -> bool:
         return bool(value)
 
